@@ -1,6 +1,37 @@
 <?php
+
+/**
+ * This file is part of the Froxlor project.
+ * Copyright (c) 2010 the Froxlor Team (see authors).
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, you can also view it online at
+ * https://files.froxlor.org/misc/COPYING.txt
+ *
+ * @copyright  the authors
+ * @author     Froxlor team <team@froxlor.org>
+ * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
+ */
+
 namespace Froxlor\Validate;
 
+use Exception;
+use Froxlor\Database\Database;
+use Froxlor\FroxlorLogger;
+use Froxlor\Idna\IdnaWrapper;
+use Froxlor\System\IPTools;
+use Froxlor\UI\Response;
+
 class Validate
 {
 
@@ -12,50 +43,47 @@ class Validate
 
 	const REGEX_DESC_TEXT = '/^[^\0\r\n<>]*$/';
 
+	const REGEX_YYYY_MM_DD = '/^\d{4}-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])$/';
+
 	/**
-	 * Validates the given string by matching against the pattern, prints an error on failure and exits
+	 * Validates the given string by matching against the pattern, prints an error on failure and exits.
+	 * If the default pattern is used and the string does not match, we try to replace the 'bad' values and log the action.
 	 *
-	 * @param string $str
-	 *        	the string to be tested (user input)
-	 * @param
-	 *        	string the $fieldname to be used in error messages
-	 * @param string $pattern
-	 *        	the regular expression to be used for testing
-	 * @param
-	 *        	string language id for the error
-	 * @return string the clean string
-	 *        
-	 *         If the default pattern is used and the string does not match, we try to replace the
-	 *         'bad' values and log the action.
-	 *        
+	 * @param string $str the string to be tested (user input)
+	 * @param string $fieldname to be used in error messages
+	 * @param string $pattern the regular expression to be used for testing
+	 * @param string|array $lng id for the error
+	 * @param string|array $emptydefault fallback value
+	 * @param bool $throw_exception whether to display error or throw an exception, default false
+	 *
+	 * @return string|void the clean string or error
 	 */
-	public static function validate($str, $fieldname, $pattern = '', $lng = '', $emptydefault = array(), $throw_exception = false)
+	public static function validate($str, string $fieldname, string $pattern = '', $lng = '', $emptydefault = [], bool $throw_exception = false)
 	{
-		if (! is_array($emptydefault)) {
-			$emptydefault_array = array(
+		if (!is_array($emptydefault)) {
+			$emptydefault_array = [
 				$emptydefault
-			);
+			];
 			unset($emptydefault);
 			$emptydefault = $emptydefault_array;
 			unset($emptydefault_array);
 		}
 
 		// Check if the $str is one of the values which represent the default for an 'empty' value
-		if (is_array($emptydefault) && ! empty($emptydefault) && in_array($str, $emptydefault)) {
+		if (is_array($emptydefault) && !empty($emptydefault) && in_array($str, $emptydefault)) {
 			return $str;
 		}
 
 		if ($pattern == '') {
-
 			$pattern = '/^[^\r\n\t\f\0]*$/D';
 
-			if (! preg_match($pattern, $str)) {
+			if (!preg_match($pattern, $str)) {
 				// Allows letters a-z, digits, space (\\040), hyphen (\\-), underscore (\\_) and backslash (\\\\),
 				// everything else is removed from the string.
 				$allowed = "/[^a-z0-9\\040\\.\\-\\_\\\\]/i";
 				$str = preg_replace($allowed, "", $str);
-				$log = \Froxlor\FroxlorLogger::getInstanceOf();
-				$log->logAction(\Froxlor\FroxlorLogger::USR_ACTION, LOG_WARNING, "cleaned bad formatted string (" . $str . ")");
+				$log = FroxlorLogger::getInstanceOf();
+				$log->logAction(FroxlorLogger::USR_ACTION, LOG_WARNING, "cleaned bad formatted string (" . $str . ")");
 			}
 		}
 
@@ -67,84 +95,58 @@ class Validate
 			$lng = 'stringformaterror';
 		}
 
-		\Froxlor\UI\Response::standard_error($lng, $fieldname, $throw_exception);
-	}
-
-	/**
-	 * Converts CIDR to a netmask address
-	 *
-	 * @thx to https://stackoverflow.com/a/5711080/3020926
-	 * @param string $cidr
-	 *
-	 * @return string
-	 */
-	public static function cidr2NetmaskAddr($cidr)
-	{
-		$ta = substr($cidr, strpos($cidr, '/') + 1) * 1;
-		$netmask = str_split(str_pad(str_pad('', $ta, '1'), 32, '0'), 8);
-
-		foreach ($netmask as &$element) {
-			$element = bindec($element);
-		}
-
-		return implode('.', $netmask);
-	}
-
-	/**
-	 * Checks if an $address (IP) is IPv6
-	 *
-	 * @param string $address
-	 *
-	 * @return string|bool ip address on success, false on failure
-	 */
-	public static function is_ipv6($address)
-	{
-		return filter_var($address, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6);
+		Response::standardError($lng, $fieldname, $throw_exception);
 	}
 
 	/**
 	 * Checks whether it is a valid ip
 	 *
 	 * @param string $ip
-	 *        	ip-address to check
+	 *            ip-address to check
 	 * @param bool $return_bool
-	 *        	whether to return bool or call \Froxlor\UI\Response::standard_error()
+	 *            whether to return bool or call \Froxlor\UI\Response::standard_error()
 	 * @param string $lng
-	 *        	index for error-message (if $return_bool is false)
+	 *            index for error-message (if $return_bool is false)
 	 * @param bool $allow_localhost
-	 *        	whether to allow 127.0.0.1
+	 *            whether to allow 127.0.0.1
 	 * @param bool $allow_priv
-	 *        	whether to allow private network addresses
+	 *            whether to allow private network addresses
 	 * @param bool $allow_cidr
-	 *        	whether to allow CIDR values e.g. 10.10.10.10/16
+	 *            whether to allow CIDR values e.g. 10.10.10.10/16
 	 * @param bool $cidr_as_netmask
-	 *        	whether to format CIDR nodation to netmask notation
+	 *            whether to format CIDR nodation to netmask notation
 	 * @param bool $throw_exception
-	 *        	whether to throw an exception on failure
-	 *        	
-	 * @return string|bool ip address on success, false on failure
+	 *            whether to throw an exception on failure
+	 *
+	 * @return string|bool|void ip address on success, false on failure (or nothing if error is displayed)
 	 */
-	public static function validate_ip2($ip, $return_bool = false, $lng = 'invalidip', $allow_localhost = false, $allow_priv = false, $allow_cidr = false, $cidr_as_netmask = false, $throw_exception = false)
+	public static function validate_ip2($ip, bool $return_bool = false, string $lng = 'invalidip', bool $allow_localhost = false, bool $allow_priv = false, bool $allow_cidr = false, bool $cidr_as_netmask = false, bool $throw_exception = false)
 	{
 		$cidr = "";
 		if ($allow_cidr) {
 			$org_ip = $ip;
 			$ip_cidr = explode("/", $ip);
 			if (count($ip_cidr) === 2) {
-				if (strlen($ip_cidr[1]) <= 2 && in_array((int) $ip_cidr[1], array_values(range(1, 32)), true) === false) {
-					\Froxlor\UI\Response::standard_error($lng, $ip, $throw_exception);
+				$cidr_range_max = 32;
+				if (IPTools::is_ipv6($ip_cidr[0])) {
+					$cidr_range_max = 128;
 				}
-				if ($cidr_as_netmask && self::is_ipv6($ip_cidr[0])) {
+				if (strlen($ip_cidr[1]) <= 3 && in_array((int)$ip_cidr[1], array_values(range(1, $cidr_range_max)), true) === false) {
+					if ($return_bool) {
+						return false;
+					}
+					Response::standardError($lng, $ip, $throw_exception);
+				}
+				if ($cidr_as_netmask && IPTools::is_ipv6($ip_cidr[0])) {
 					// MySQL does not handle CIDR of IPv6 addresses, return error
 					if ($return_bool) {
 						return false;
-					} else {
-						\Froxlor\UI\Response::standard_error($lng, $ip, $throw_exception);
 					}
+					Response::standardError($lng, $ip, $throw_exception);
 				}
 				$ip = $ip_cidr[0];
-				if ($cidr_as_netmask && strlen($ip_cidr[1]) <= 2) {
-					$ip_cidr[1] = self::cidr2NetmaskAddr($org_ip);
+				if ($cidr_as_netmask && strlen($ip_cidr[1]) <= 3) {
+					$ip_cidr[1] = IPTools::cidr2NetmaskAddr($org_ip);
 				}
 				$cidr = "/" . $ip_cidr[1];
 			} else {
@@ -153,9 +155,8 @@ class Validate
 		} elseif (strpos($ip, "/") !== false) {
 			if ($return_bool) {
 				return false;
-			} else {
-				\Froxlor\UI\Response::standard_error($lng, $ip, $throw_exception);
 			}
+			Response::standardError($lng, $ip, $throw_exception);
 		}
 
 		$filter_lan = $allow_priv ? FILTER_FLAG_NO_RES_RANGE : (FILTER_FLAG_NO_RES_RANGE | FILTER_FLAG_NO_PRIV_RANGE);
@@ -171,20 +172,21 @@ class Validate
 
 		if ($return_bool) {
 			return false;
-		} else {
-			\Froxlor\UI\Response::standard_error($lng, $ip, $throw_exception);
 		}
+		Response::standardError($lng, $ip, $throw_exception);
 	}
 
 	/**
 	 * Returns whether a URL is in a correct format or not
 	 *
 	 * @param string $url
-	 *        	URL to be tested
-	 *        	
+	 *            URL to be tested
+	 * @param bool $allow_private_ip
+	 *          optional, default is false
+	 *
 	 * @return bool
 	 */
-	public static function validateUrl($url)
+	public static function validateUrl(string $url, bool $allow_private_ip = false)
 	{
 		if (strtolower(substr($url, 0, 7)) != "http://" && strtolower(substr($url, 0, 8)) != "https://") {
 			$url = 'http://' . $url;
@@ -192,13 +194,17 @@ class Validate
 
 		// needs converting
 		try {
-			$idna_convert = new \Froxlor\Idna\IdnaWrapper();
+			$idna_convert = new IdnaWrapper();
 			$url = $idna_convert->encode($url);
-		} catch (\Exception $e) {
+		} catch (Exception $e) {
 			return false;
 		}
 
-		$pattern = '%^(?:(?:https?)://)(?:\S+(?::\S*)?@)?(?:(?!10(?:\.\d{1,3}){3})(?!127(?:\.\d{1,3}){3})(?!169\.254(?:\.\d{1,3}){2})(?!192\.168(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\x{00a1}-\x{ffff}0-9]+-?)*[a-z\x{00a1}-\x{ffff}0-9]+)(?:\.(?:[a-z\x{00a1}-\x{ffff}0-9]+-?)*[a-z\x{00a1}-\x{ffff}0-9]+)*(?:\.(?:[a-z\x{00a1}-\x{ffff}]{2,})))(?::\d{2,5})?(?:/[^\s]*)?$%iuS';
+		if ($allow_private_ip) {
+			$pattern = '%^(?:(?:https?):\/\/)(?:\S+(?::\S*)?@)?(?:(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\x{00a1}-\x{ffff}0-9]+-?)*[a-z\x{00a1}-\x{ffff}0-9]+)(?:\.(?:[a-z\x{00a1}-\x{ffff}0-9]+-?)*[a-z\x{00a1}-\x{ffff}0-9]+)*(?:\.(?:[a-z\x{00a1}-\x{ffff}]{2,})))(?::\d{2,5})?(?:\/[^\s]*)?$%iuS';
+		} else {
+			$pattern = '%^(?:(?:https?):\/\/)(?:\S+(?::\S*)?@)?(?:(?!10(?:\.\d{1,3}){3})(?!127(?:\.\d{1,3}){3})(?!169\.254(?:\.\d{1,3}){2})(?!192\.168(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\x{00a1}-\x{ffff}0-9]+-?)*[a-z\x{00a1}-\x{ffff}0-9]+)(?:\.(?:[a-z\x{00a1}-\x{ffff}0-9]+-?)*[a-z\x{00a1}-\x{ffff}0-9]+)*(?:\.(?:[a-z\x{00a1}-\x{ffff}]{2,})))(?::\d{2,5})?(?:/[^\s]*)?$%iuS';
+		}
 		if (preg_match($pattern, $url)) {
 			return true;
 		}
@@ -210,10 +216,10 @@ class Validate
 	 * Check if the submitted string is a valid domainname
 	 *
 	 * @param string $domainname
-	 *        	The domainname which should be checked.
+	 *            The domainname which should be checked.
 	 * @param bool $allow_underscore
-	 *        	optional if true, allowes the underscore character in a domain label (DKIM etc.)
-	 *        	
+	 *            optional if true, allowes the underscore character in a domain label (DKIM etc.)
+	 *
 	 * @return string|boolean the domain-name if the domain is valid, false otherwise
 	 */
 	public static function validateDomain($domainname, $allow_underscore = false)
@@ -252,7 +258,7 @@ class Validate
 	 * Returns if an emailaddress is in correct format or not
 	 *
 	 * @param string $email
-	 *        	The email address to check
+	 *            The email address to check
 	 * @return bool Correct or not
 	 */
 	public static function validateEmail($email)
@@ -269,20 +275,20 @@ class Validate
 	 * Returns if an username is in correct format or not.
 	 *
 	 * @param string $username
-	 *        	The username to check
+	 *            The username to check
 	 * @param bool $unix_names
-	 *        	optional, default true, checks whether it must be UNIX compatible
+	 *            optional, default true, checks whether it must be UNIX compatible
 	 * @param int $mysql_max
-	 *        	optional, number of max mysql username characters, default empty
-	 *        	
+	 *            optional, number of max mysql username characters, default empty
+	 *
 	 * @return bool
 	 */
 	public static function validateUsername($username, $unix_names = 1, $mysql_max = '')
 	{
-		if (empty($mysql_max) || ! is_numeric($mysql_max) || $mysql_max <= 0) {
-			$mysql_max = \Froxlor\Database\Database::getSqlUsernameLength() - 1;
+		if (empty($mysql_max) || !is_numeric($mysql_max) || $mysql_max <= 0) {
+			$mysql_max = Database::getSqlUsernameLength() - 1;
 		} else {
-			$mysql_max --;
+			$mysql_max--;
 		}
 		if ($unix_names == 0) {
 			if (strpos($username, '--') === false) {
@@ -302,12 +308,12 @@ class Validate
 	 */
 	public static function validateSqlInterval($interval = null)
 	{
-		if (! empty($interval) && strstr($interval, ' ') !== false) {
+		if (!empty($interval) && strstr($interval, ' ') !== false) {
 			/*
 			 * [0] = ([0-9]+)
 			 * [1] = valid SQL-Interval expression
 			 */
-			$valid_expr = array(
+			$valid_expr = [
 				'SECOND',
 				'MINUTE',
 				'HOUR',
@@ -315,7 +321,7 @@ class Validate
 				'WEEK',
 				'MONTH',
 				'YEAR'
-			);
+			];
 
 			$interval_parts = explode(' ', $interval);
 
